# coding: utf-8

"""
    Radarr

    Radarr API docs

    The version of the OpenAPI document: v5.8.3.8933
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from radarr.models.download_protocol import DownloadProtocol
from typing import Optional, Set
from typing_extensions import Self

class DelayProfileResource(BaseModel):
    """
    DelayProfileResource
    """ # noqa: E501
    id: Optional[StrictInt] = None
    enable_usenet: Optional[StrictBool] = Field(default=None, alias="enableUsenet")
    enable_torrent: Optional[StrictBool] = Field(default=None, alias="enableTorrent")
    preferred_protocol: Optional[DownloadProtocol] = Field(default=None, alias="preferredProtocol")
    usenet_delay: Optional[StrictInt] = Field(default=None, alias="usenetDelay")
    torrent_delay: Optional[StrictInt] = Field(default=None, alias="torrentDelay")
    bypass_if_highest_quality: Optional[StrictBool] = Field(default=None, alias="bypassIfHighestQuality")
    bypass_if_above_custom_format_score: Optional[StrictBool] = Field(default=None, alias="bypassIfAboveCustomFormatScore")
    minimum_custom_format_score: Optional[StrictInt] = Field(default=None, alias="minimumCustomFormatScore")
    order: Optional[StrictInt] = None
    tags: Optional[List[StrictInt]] = None
    __properties: ClassVar[List[str]] = ["id", "enableUsenet", "enableTorrent", "preferredProtocol", "usenetDelay", "torrentDelay", "bypassIfHighestQuality", "bypassIfAboveCustomFormatScore", "minimumCustomFormatScore", "order", "tags"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DelayProfileResource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if tags (nullable) is None
        # and model_fields_set contains the field
        if self.tags is None and "tags" in self.model_fields_set:
            _dict['tags'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DelayProfileResource from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "enableUsenet": obj.get("enableUsenet"),
            "enableTorrent": obj.get("enableTorrent"),
            "preferredProtocol": obj.get("preferredProtocol"),
            "usenetDelay": obj.get("usenetDelay"),
            "torrentDelay": obj.get("torrentDelay"),
            "bypassIfHighestQuality": obj.get("bypassIfHighestQuality"),
            "bypassIfAboveCustomFormatScore": obj.get("bypassIfAboveCustomFormatScore"),
            "minimumCustomFormatScore": obj.get("minimumCustomFormatScore"),
            "order": obj.get("order"),
            "tags": obj.get("tags")
        })
        return _obj


